version 8.0

* dsfgt.ado
*
* David Stifel
* Dept. of Economics & Business
* Lafayette College
* e-mail: stifeld@lafayette.edu
*
*
* Program to estimate FGT poverty (alpha = 0, 1, 2)
* and the variance
*
* Note: Variance of FGT measure is for a simple
*       random sample and is derived in Kakwani
*       (1993, ReStat)...
*       V(Palpha) = (1/n)*(P2alpha - Palpha^2)
*
*       Where n = sample size - 1
*
* Syntax is "dsfgt var wgt z"

program define dsfgt
  local var `1'
  local wgt `2'
  local z   `3'

  tempvar gap0 gap1 gap2 gap4
  qui gen `gap0' = `var' < `z'
  qui replace `gap0' = . if `var' == .
  qui gen `gap1' = `gap0'*(`z' - `var')/`z'
  qui gen `gap2' = `gap1'^2 
  qui gen `gap4' = `gap1'^4
  summ `gap0' [aw=`wgt'], meanonly
   global P0   = r(mean)
   local  P0_2 = r(mean)^2
   local  n    = r(N) - 1
  summ `gap1' [aw=`wgt'], meanonly
   global P1   = r(mean)
   local  P1_2 = r(mean)^2
  summ `gap2' [aw=`wgt'], meanonly
   global P2   = r(mean)
   local  P2_2 = r(mean)^2
  summ `gap4' [aw=`wgt'], meanonly
   local  P4_2 = r(mean)^2

  global VP0 =     (1/`n')*($P0 - `P0_2')
  global VP1 =     (1/`n')*($P2 - `P1_2')
  global VP2 = abs((1/`n')*(`P4'- `P2_2'))

  display ""
  display in gr "    |       Poverty       Std. Dev"
  display in gr "----+-----------------------------------------"
  display in gr " P0 |       " in y %5.4f $P0 "        " %7.6f sqrt($VP0) 
  display in gr " P1 |       " in y %5.4f $P1 "        " %7.6f sqrt($VP1) 
  display in gr " P2 |       " in y %5.4f $P2 "        " %7.6f sqrt($VP2) 
  display in gr "----+-----------------------------------------"
  display ""

end
